use sea_orm_migration::prelude::*;

use crate::m20230204_194846_create_menus::Menu;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(MenuEntry::Table)
                    .if_not_exists()
                    .col(ColumnDef::new(MenuEntry::Id)
                            .string()
                            .not_null()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(MenuEntry::Owner).string().not_null())
                    .col(ColumnDef::new(MenuEntry::Order).integer().not_null())
                    .col(ColumnDef::new(MenuEntry::Text).text().not_null())
                    .col(ColumnDef::new(MenuEntry::ReferringSlug).text().not_null())
                    .foreign_key(ForeignKey::create()
                        .name("fk-menu_entries-menus")
                        .from(MenuEntry::Table, MenuEntry::Owner)
                        .to(Menu::Table, Menu::Id)
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(MenuEntry::Table).to_owned())
            .await
    }
}

/// Learn more at https://docs.rs/sea-query#iden
#[derive(Iden)]
enum MenuEntry {
    Table,
    Id,
    Owner,
    Order,
    Text,
    ReferringSlug,
}
