use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Settings::Table)
                    .if_not_exists()
                    .col(
                            ColumnDef::new(Settings::Id)
                            .string()
                            .not_null()
                            .primary_key(),
                    )
                    .col(ColumnDef::new(Settings::SiteName).text().not_null())
                    .col(ColumnDef::new(Settings::SiteHeader).text().not_null())
                    .col(ColumnDef::new(Settings::SiteOwner).text().not_null())
                    .col(ColumnDef::new(Settings::SiteAdditionalHead).text())
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(Settings::Table).to_owned())
            .await
    }
}

/// Learn more at https://docs.rs/sea-query#iden
#[derive(Iden)]
enum Settings {
    Table,
    Id,
    SiteName,
    SiteHeader,
    SiteOwner,
    SiteAdditionalHead
}
