use askama::Template;
use askama_axum::IntoResponse;
use axum::extract::State;

use crate::AppState;

use sea_orm::*;
use crate::entities::{prelude::*, *};

#[derive(Template)]
#[template(path = "posts_listing.html")]
pub(crate) struct PageTemplate {
    menu: Vec<menu_entry::Model>,
    posts: Vec<post::Model>,
    year: String,
    settings: settings::Model
}

pub(crate) async fn posts(state: State<AppState>) -> impl IntoResponse {
    let menu: Vec<menu_entry::Model> = Menu::find()
        .filter(menu::Column::Name.eq("primary"))
        .one(&state.db_conn)
        .await
        .expect("Failed to get primary menu! HALTING")
        .unwrap()
        .find_related(MenuEntry)
        .order_by_asc(menu_entry::Column::Order)
        .all(&state.db_conn)
        .await
        .expect("Failed to get primary menu items!");

    let settings: settings::Model = Settings::find()
        .filter(settings::Column::Id.eq("current"))
        .one(&state.db_conn)
        .await
        .expect("Failed to get site settings!")
        .unwrap();

    let posts: Vec<post::Model> = Post::find()
        .filter(post::Column::Draft.eq(false))
        .order_by_desc(post::Column::Published)
        .all(&state.db_conn)
        .await
        .expect("Failed to load posts!");

    PageTemplate { menu, posts, year: "2023".to_owned(), settings }
}
